Record

Struct Record 

pub struct Record<K, V> { /* private fields */ }
WebIDL record<K, V> wrapper. No concrete JS type, but needed for WebIDL

Implementations

Source

impl<K, V> Record<K, V>

pub fn new() -> Self

pub fn set(&self, item: K, val: V)
where Val: From<K> + From<V>,

Set keyed item to val

pub fn get(&self, item: K) -> Option<V>
where Val: From<K> + From<V>, V: FromVal,

Get the value of the key item

pub fn has(&self, item: K) -> bool
where Val: From<K>,

Returns whether a value exists in the Record.

pub fn size(&self) -> usize

Gets the number of properties in the object Note: JavaScript objects don’t have a built-in size property like arrays, so this counts enumerable properties using Object.keys()

Methods from Deref<Target = Val>

pub fn get<T>(&self, prop: T) -> Val
where T: Into<Val>,

Gets the property prop

pub fn set<K, V>(&self, prop: K, val: V)
where K: Into<Val>, V: Into<Val>,

Set the underlying js object property prop to val

pub fn has<T>(&self, prop: T) -> bool
where T: Into<Val>,

Checks whether a property prop exists

pub fn has_own_property(&self, prop: &str) -> bool

Checks whether a non-inherited property prop exists

pub fn type_of(&self) -> String

Gets the typeof the underlying js object

pub fn at<T>(&self, idx: T) -> Val
where T: Into<Val>,

Gets the element at index idx. Assumes the underlying js type is indexable

pub fn to_vec<V>(&self) -> Vec<V>
where V: FromVal,

Converts the underlying js array to a Vec of V

pub fn call(&self, f: &str, args: &[Val]) -> Val

Calls the method f with args, can return an undefined js value

pub fn new(&self, args: &[Val]) -> Val

Calls the object’s constructor with args constructing a new object

pub fn invoke(&self, args: &[Val]) -> Val

Invokes the function object with args, can return an undefined js value

pub fn await_(&self) -> Val

Awaits the invoked function object

pub fn instanceof(&self, v: Val) -> bool

Checks whether this Val is an instanceof v

pub fn is_number(&self) -> bool

pub fn is_bool(&self) -> bool

pub fn is_string(&self) -> bool

pub fn is_null(&self) -> bool

pub fn is_undefined(&self) -> bool

pub fn is_error(&self) -> bool

pub fn is_function(&self) -> bool

pub fn as_<T>(&self) -> T
where T: FromVal,

Examples found in repository?
examples/any.rs (line 15)
3fn main() {
4    emlite::init();
5    // Create Any from different Rust types
6    let num = Any::from(123);
7    let text = Any::from("hello");
8    let boolean = Any::from(true);
9    println!("Any from int: {:?}", num);
10    println!("Any from str: {:?}", text);
11    println!("Any from bool: {:?}", boolean);
12    Console::get().log(&[num.clone(), text.clone(), boolean.clone()]);
13
14    // Convert Any back to Rust types using as_::<T>()
15    let n: i32 = num.as_();
16    let s: Option<String> = text.as_();
17    let b: bool = boolean.as_();
18    println!("Extracted i32: {}", n);
19    println!("Extracted String: {:?}", s);
20    println!("Extracted bool: {}", b);
21}
More examples
Hide additional examples
examples/closures.rs (line 10)
4fn main() {
5    emlite::init();
6
7    // 0-arg closure returning a number
8    let c0 = Closure::bind0(|| 42);
9    let f0: Function = (&c0).into();
10    let r0 = f0.call(&Any::undefined(), &[]).unwrap().as_::<i32>();
11    Console::get().log(&[Any::from(r0)]);
12
13    // 1-arg closure: add 1
14    let c1 = Closure::bind1(|x: i32| x + 1);
15    let f1: Function = (&c1).into();
16    let r1 = f1
17        .call(&Any::undefined(), &[Any::from(9)])
18        .unwrap()
19        .as_::<i32>();
20    Console::get().log(&[Any::from(r1)]);
21
22    // 2-arg closure: sum
23    let c2 = Closure::bind2(|a: i32, b: i32| a + b);
24    let f2: Function = (&c2).into();
25    let r2 = f2
26        .call(&Any::undefined(), &[Any::from(2), Any::from(3)])
27        .unwrap()
28        .as_::<i32>();
29    Console::get().log(&[Any::from(r2)]);
30
31    // 3-arg closure: format string
32    let c3 = Closure::bind3(|a: i32, b: i32, c: i32| format!("{}-{}-{}", a, b, c));
33    let f3: Function = (&c3).into();
34    let r3 = f3
35        .call(
36            &Any::undefined(),
37            &[Any::from(1), Any::from(2), Any::from(3)],
38        )
39        .unwrap()
40        .as_::<Option<String>>()
41        .unwrap();
42    Console::get().log(&[Any::from(r3)]);
43
44    // 4-arg closure: sum of four
45    let c4 = Closure::bind4(|a: i32, b: i32, c: i32, d: i32| a + b + c + d);
46    let f4: Function = (&c4).into();
47    let r4 = f4
48        .call(
49            &Any::undefined(),
50            &[Any::from(1), Any::from(2), Any::from(3), Any::from(4)],
51        )
52        .unwrap()
53        .as_::<i32>();
54    Console::get().log(&[Any::from(r4)]);
55}
pub fn to_utf16(&self) -> Option<Vec<u16>>

Extracts UTF-16 data as Option<Vec>

pub fn to_utf16_result(&self) -> Result<Vec<u16>, Val>

Extracts UTF-16 data, returning error if null or if self is error