pub struct TextEncoder { /* private fields */ }Expand description
JavaScript TextEncoder (new TextEncoder()).
Implementations
Sourceimpl TextEncoder
impl TextEncoder
Sourcepub fn encode(&self, s: &str) -> Uint8Array
pub fn encode(&self, s: &str) -> Uint8Array
encoder.encode(str) → Uint8Array
Sourcepub fn encode_into(&self, src: &str, dst: &mut Uint8Array) -> (usize, usize)
pub fn encode_into(&self, src: &str, dst: &mut Uint8Array) -> (usize, usize)
encoder.encodeInto(src, dst) → { read, written }
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
Sourcepub fn as_<T>(&self) -> Twhere
T: FromVal,
pub fn as_<T>(&self) -> Twhere
T: FromVal,
Examples found in repository?
examples/any.rs (line 15)
3fn main() {
4 emlite::init();
5 // Create Any from different Rust types
6 let num = Any::from(123);
7 let text = Any::from("hello");
8 let boolean = Any::from(true);
9 println!("Any from int: {:?}", num);
10 println!("Any from str: {:?}", text);
11 println!("Any from bool: {:?}", boolean);
12 Console::get().log(&[num.clone(), text.clone(), boolean.clone()]);
13
14 // Convert Any back to Rust types using as_::<T>()
15 let n: i32 = num.as_();
16 let s: Option<String> = text.as_();
17 let b: bool = boolean.as_();
18 println!("Extracted i32: {}", n);
19 println!("Extracted String: {:?}", s);
20 println!("Extracted bool: {}", b);
21}More examples
examples/closures.rs (line 10)
4fn main() {
5 emlite::init();
6
7 // 0-arg closure returning a number
8 let c0 = Closure::bind0(|| 42);
9 let f0: Function = (&c0).into();
10 let r0 = f0.call(&Any::undefined(), &[]).unwrap().as_::<i32>();
11 Console::get().log(&[Any::from(r0)]);
12
13 // 1-arg closure: add 1
14 let c1 = Closure::bind1(|x: i32| x + 1);
15 let f1: Function = (&c1).into();
16 let r1 = f1
17 .call(&Any::undefined(), &[Any::from(9)])
18 .unwrap()
19 .as_::<i32>();
20 Console::get().log(&[Any::from(r1)]);
21
22 // 2-arg closure: sum
23 let c2 = Closure::bind2(|a: i32, b: i32| a + b);
24 let f2: Function = (&c2).into();
25 let r2 = f2
26 .call(&Any::undefined(), &[Any::from(2), Any::from(3)])
27 .unwrap()
28 .as_::<i32>();
29 Console::get().log(&[Any::from(r2)]);
30
31 // 3-arg closure: format string
32 let c3 = Closure::bind3(|a: i32, b: i32, c: i32| format!("{}-{}-{}", a, b, c));
33 let f3: Function = (&c3).into();
34 let r3 = f3
35 .call(
36 &Any::undefined(),
37 &[Any::from(1), Any::from(2), Any::from(3)],
38 )
39 .unwrap()
40 .as_::<Option<String>>()
41 .unwrap();
42 Console::get().log(&[Any::from(r3)]);
43
44 // 4-arg closure: sum of four
45 let c4 = Closure::bind4(|a: i32, b: i32, c: i32, d: i32| a + b + c + d);
46 let f4: Function = (&c4).into();
47 let r4 = f4
48 .call(
49 &Any::undefined(),
50 &[Any::from(1), Any::from(2), Any::from(3), Any::from(4)],
51 )
52 .unwrap()
53 .as_::<i32>();
54 Console::get().log(&[Any::from(r4)]);
55}Trait Implementations
Sourceimpl AsMut<Val> for TextEncoder
impl AsMut<Val> for TextEncoder
Sourceimpl AsRef<Val> for TextEncoder
impl AsRef<Val> for TextEncoder
Sourceimpl Clone for TextEncoder
impl Clone for TextEncoder
Sourcefn clone(&self) -> TextEncoder
fn clone(&self) -> TextEncoder
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TextEncoder
impl Debug for TextEncoder
Sourceimpl Default for TextEncoder
impl Default for TextEncoder
Sourceimpl Deref for TextEncoder
impl Deref for TextEncoder
Sourceimpl DerefMut for TextEncoder
impl DerefMut for TextEncoder
Sourceimpl DynCast for TextEncoder
impl DynCast for TextEncoder
Sourcefn instanceof(val: &Any) -> bool
fn instanceof(val: &Any) -> bool
Implementation of
val instanceof ThisType.Sourcefn unchecked_from_val(v: Any) -> Self
fn unchecked_from_val(v: Any) -> Self
Zero-cost unchecked conversion from
Val into Self.Sourcefn unchecked_from_val_ref(v: &Any) -> &Self
fn unchecked_from_val_ref(v: &Any) -> &Self
Zero-cost unchecked conversion from
&Val into &Self.Sourcefn unchecked_from_val_mut(v: &mut Any) -> &mut Self
fn unchecked_from_val_mut(v: &mut Any) -> &mut Self
Zero-cost unchecked conversion from
&mut Val into &mut Self.fn has_type<T>(&self) -> boolwhere
T: DynCast,
fn dyn_into<T>(self) -> Result<T, Self>where
T: DynCast,
fn dyn_ref<T>(&self) -> Option<&T>where
T: DynCast,
fn dyn_mut<T>(&mut self) -> Option<&mut T>where
T: DynCast,
fn unchecked_into<T>(self) -> Twhere
T: DynCast,
fn unchecked_ref<T>(&self) -> &Twhere
T: DynCast,
fn unchecked_mut<T>(&mut self) -> &mut Twhere
T: DynCast,
fn is_instance_of<T>(&self) -> boolwhere
T: DynCast,
Sourcefn is_type_of(val: &Val) -> bool
fn is_type_of(val: &Val) -> bool
Customisable brand check – defaults to
instanceof.Sourceimpl From<&TextEncoder> for Any
impl From<&TextEncoder> for Any
Sourcefn from(x: &TextEncoder) -> Any
fn from(x: &TextEncoder) -> Any
Converts to this type from the input type.
Sourceimpl From<TextEncoder> for Any
impl From<TextEncoder> for Any
Sourcefn from(x: TextEncoder) -> Any
fn from(x: TextEncoder) -> Any
Converts to this type from the input type.
Sourceimpl FromVal for TextEncoder
impl FromVal for TextEncoder
Sourceimpl PartialEq for TextEncoder
impl PartialEq for TextEncoder
Sourceimpl PartialOrd for TextEncoder
impl PartialOrd for TextEncoder
impl StructuralPartialEq for TextEncoder