pub struct TypedWeakSet<T> { /* private fields */ }Expand description
TypedWeakSet<T> – Typed wrapper around ECMAScript “WeakSet” (new WeakSet()).
Implementations
Sourceimpl<T> TypedWeakSet<T>
impl<T> TypedWeakSet<T>
Sourcepub fn get(&self, idx: usize) -> Option<T>where
T: FromVal,
pub fn get(&self, idx: usize) -> Option<T>where
T: FromVal,
Return a copy of the element at idx converted to T.
pub fn set(&self, idx: usize, val: T)
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
Methods from Deref<Target = Val>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
Sourcepub fn as_<T>(&self) -> Twhere
T: FromVal,
pub fn as_<T>(&self) -> Twhere
T: FromVal,
Examples found in repository?
examples/any.rs (line 15)
3fn main() {
4 emlite::init();
5 // Create Any from different Rust types
6 let num = Any::from(123);
7 let text = Any::from("hello");
8 let boolean = Any::from(true);
9 println!("Any from int: {:?}", num);
10 println!("Any from str: {:?}", text);
11 println!("Any from bool: {:?}", boolean);
12 Console::get().log(&[num.clone(), text.clone(), boolean.clone()]);
13
14 // Convert Any back to Rust types using as_::<T>()
15 let n: i32 = num.as_();
16 let s: Option<String> = text.as_();
17 let b: bool = boolean.as_();
18 println!("Extracted i32: {}", n);
19 println!("Extracted String: {:?}", s);
20 println!("Extracted bool: {}", b);
21}More examples
examples/closures.rs (line 10)
4fn main() {
5 emlite::init();
6
7 // 0-arg closure returning a number
8 let c0 = Closure::bind0(|| 42);
9 let f0: Function = (&c0).into();
10 let r0 = f0.call(&Any::undefined(), &[]).unwrap().as_::<i32>();
11 Console::get().log(&[Any::from(r0)]);
12
13 // 1-arg closure: add 1
14 let c1 = Closure::bind1(|x: i32| x + 1);
15 let f1: Function = (&c1).into();
16 let r1 = f1
17 .call(&Any::undefined(), &[Any::from(9)])
18 .unwrap()
19 .as_::<i32>();
20 Console::get().log(&[Any::from(r1)]);
21
22 // 2-arg closure: sum
23 let c2 = Closure::bind2(|a: i32, b: i32| a + b);
24 let f2: Function = (&c2).into();
25 let r2 = f2
26 .call(&Any::undefined(), &[Any::from(2), Any::from(3)])
27 .unwrap()
28 .as_::<i32>();
29 Console::get().log(&[Any::from(r2)]);
30
31 // 3-arg closure: format string
32 let c3 = Closure::bind3(|a: i32, b: i32, c: i32| format!("{}-{}-{}", a, b, c));
33 let f3: Function = (&c3).into();
34 let r3 = f3
35 .call(
36 &Any::undefined(),
37 &[Any::from(1), Any::from(2), Any::from(3)],
38 )
39 .unwrap()
40 .as_::<Option<String>>()
41 .unwrap();
42 Console::get().log(&[Any::from(r3)]);
43
44 // 4-arg closure: sum of four
45 let c4 = Closure::bind4(|a: i32, b: i32, c: i32, d: i32| a + b + c + d);
46 let f4: Function = (&c4).into();
47 let r4 = f4
48 .call(
49 &Any::undefined(),
50 &[Any::from(1), Any::from(2), Any::from(3), Any::from(4)],
51 )
52 .unwrap()
53 .as_::<i32>();
54 Console::get().log(&[Any::from(r4)]);
55}Trait Implementations
Sourceimpl<T> AsMut<Val> for TypedWeakSet<T>
impl<T> AsMut<Val> for TypedWeakSet<T>
Sourceimpl<T> AsRef<Val> for TypedWeakSet<T>
impl<T> AsRef<Val> for TypedWeakSet<T>
Sourceimpl<T: Clone> Clone for TypedWeakSet<T>
impl<T: Clone> Clone for TypedWeakSet<T>
Sourcefn clone(&self) -> TypedWeakSet<T>
fn clone(&self) -> TypedWeakSet<T>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T: Debug> Debug for TypedWeakSet<T>
impl<T: Debug> Debug for TypedWeakSet<T>
Sourceimpl<T> Default for TypedWeakSet<T>
impl<T> Default for TypedWeakSet<T>
Sourceimpl<T> Deref for TypedWeakSet<T>
impl<T> Deref for TypedWeakSet<T>
Sourceimpl<T> DerefMut for TypedWeakSet<T>
impl<T> DerefMut for TypedWeakSet<T>
Sourceimpl<T> Display for TypedWeakSet<T>
impl<T> Display for TypedWeakSet<T>
Sourceimpl<T> From<&TypedWeakSet<T>> for Val
impl<T> From<&TypedWeakSet<T>> for Val
Sourcefn from(x: &TypedWeakSet<T>) -> Val
fn from(x: &TypedWeakSet<T>) -> Val
Converts to this type from the input type.
Sourceimpl<T> From<TypedWeakSet<T>> for Val
impl<T> From<TypedWeakSet<T>> for Val
Sourcefn from(x: TypedWeakSet<T>) -> Val
fn from(x: TypedWeakSet<T>) -> Val
Converts to this type from the input type.
Sourceimpl<T> FromIterator<T> for TypedWeakSet<T>
impl<T> FromIterator<T> for TypedWeakSet<T>
Sourcefn from_iter<I: IntoIterator<Item = T>>(iter: I) -> Self
fn from_iter<I: IntoIterator<Item = T>>(iter: I) -> Self
Creates a value from an iterator. Read more
Sourceimpl<T> FromVal for TypedWeakSet<T>
impl<T> FromVal for TypedWeakSet<T>
Sourceimpl<'a, T> IntoIterator for &'a TypedWeakSet<T>where
T: FromVal,
impl<'a, T> IntoIterator for &'a TypedWeakSet<T>where
T: FromVal,
Sourceimpl<T: PartialEq> PartialEq for TypedWeakSet<T>
impl<T: PartialEq> PartialEq for TypedWeakSet<T>
Sourceimpl<T: PartialOrd> PartialOrd for TypedWeakSet<T>
impl<T: PartialOrd> PartialOrd for TypedWeakSet<T>
impl<T> StructuralPartialEq for TypedWeakSet<T>