Struct CSSOMString

pub struct CSSOMString { /* private fields */ }
Wrapper for WebIDL CSSOMString.

Implementations

Source

impl CSSOMString

pub fn byte_len(&self) -> usize

Number of UTF‑8 bytes (same as str::len()).

pub fn is_empty(&self) -> bool

len() == 0 convenience.

pub fn char_at(&self, i: usize) -> Option<char>

Scalar lookup; returns None if index is out of bounds.

pub fn as_str(&self) -> &str

Borrow the JavaScript string as &str (UTF‑8 view).

pub fn length(&self) -> usize

Number of UTF-16 code units (JSString.length).

pub fn char_code_at(&self, idx: usize) -> u16

Returns the 16-bit code unit at idx (like charCodeAt).

pub fn set(&self, idx: usize, val: char)

pub fn at(&self, idx: isize) -> Option<Self>

pub fn code_point_at(&self, idx: usize) -> Option<u32>

pub fn concat(&self, rhs: &Self) -> Self

pub fn ends_with(&self, pat: &str) -> bool

pub fn includes(&self, pat: &str) -> bool

pub fn index_of(&self, pat: &str) -> Option<usize>

String.prototype.indexOf Returns None when not found.

pub fn is_well_formed(&self) -> bool

pub fn last_index_of(&self, pat: &str) -> Option<usize>

pub fn locale_compare(&self, other: &str) -> i32

pub fn match_(&self, pat: &Val) -> Val

pub fn match_all(&self, pat: &Val) -> Val

pub fn normalize(&self, form: Option<&str>) -> Self

pub fn pad_end(&self, target_len: usize, pad: Option<&str>) -> Self

pub fn pad_start(&self, target_len: usize, pad: Option<&str>) -> Self

pub fn repeat(&self, count: usize) -> Self

pub fn replace(&self, pat: &Val, repl: &Val) -> Self

pub fn replace_all(&self, pat: &Val, repl: &Val) -> Self

pub fn search(&self, pat: &Val) -> isize

pub fn slice(&self, start: isize, end: Option<isize>) -> Self

pub fn split(&self, sep: &str) -> Sequence<Self>

pub fn starts_with(&self, pat: &str) -> bool

pub fn substring(&self, start: usize, end: Option<usize>) -> Self

pub fn to_locale_lower_case(&self) -> Self

pub fn to_locale_upper_case(&self) -> Self

pub fn to_lower_case(&self) -> Self

pub fn to_upper_case(&self) -> Self

pub fn to_well_formed(&self) -> Self

pub fn trim(&self) -> Self

pub fn trim_end(&self) -> Self

pub fn trim_start(&self) -> Self

Methods from Deref<Target = Val>

pub fn get<T>(&self, prop: T) -> Val
where T: Into<Val>,

Gets the property prop

pub fn set<K, V>(&self, prop: K, val: V)
where K: Into<Val>, V: Into<Val>,

Set the underlying js object property prop to val

pub fn has<T>(&self, prop: T) -> bool
where T: Into<Val>,

Checks whether a property prop exists

pub fn has_own_property(&self, prop: &str) -> bool

Checks whether a non-inherited property prop exists

pub fn type_of(&self) -> String

Gets the typeof the underlying js object

pub fn at<T>(&self, idx: T) -> Val
where T: Into<Val>,

Gets the element at index idx. Assumes the underlying js type is indexable

pub fn to_vec<V>(&self) -> Vec<V>
where V: FromVal,

Converts the underlying js array to a Vec of V

pub fn call(&self, f: &str, args: &[Val]) -> Val

Calls the method f with args, can return an undefined js value

pub fn new(&self, args: &[Val]) -> Val

Calls the object’s constructor with args constructing a new object

pub fn invoke(&self, args: &[Val]) -> Val

Invokes the function object with args, can return an undefined js value

pub fn await_(&self) -> Val

Awaits the invoked function object

pub fn instanceof(&self, v: Val) -> bool

Checks whether this Val is an instanceof v

pub fn is_number(&self) -> bool

pub fn is_string(&self) -> bool

pub fn is_null(&self) -> bool

pub fn is_undefined(&self) -> bool

pub fn is_error(&self) -> bool

pub fn is_function(&self) -> bool

pub fn as_<T>(&self) -> T
where T: FromVal,