Struct Record

pub struct Record<K, V> { /* private fields */ }
Web‑IDL record<K, V> wrapper.

Implementations

Source

impl<K, V> Record<K, V>

pub fn set(&self, item: K, val: V)
where Val: From<K> + From<V>,

pub fn get(&self, item: K) -> V
where Val: From<K> + From<V>, V: FromVal,

pub fn has(&self, item: K) -> bool
where Val: From<K>,

Returns whether a value exists in the sequence.

Methods from Deref<Target = Val>

pub fn get<T>(&self, prop: T) -> Val
where T: Into<Val>,

Gets the property prop

pub fn set<K, V>(&self, prop: K, val: V)
where K: Into<Val>, V: Into<Val>,

Set the underlying js object property prop to val

pub fn has<T>(&self, prop: T) -> bool
where T: Into<Val>,

Checks whether a property prop exists

pub fn has_own_property(&self, prop: &str) -> bool

Checks whether a non-inherited property prop exists

pub fn type_of(&self) -> String

Gets the typeof the underlying js object

pub fn at<T>(&self, idx: T) -> Val
where T: Into<Val>,

Gets the element at index idx. Assumes the underlying js type is indexable

pub fn to_vec<V>(&self) -> Vec<V>
where V: FromVal,

Converts the underlying js array to a Vec of V

pub fn call(&self, f: &str, args: &[Val]) -> Val

Calls the method f with args, can return an undefined js value

pub fn new(&self, args: &[Val]) -> Val

Calls the object’s constructor with args constructing a new object

pub fn invoke(&self, args: &[Val]) -> Val

Invokes the function object with args, can return an undefined js value

pub fn await_(&self) -> Val

Awaits the invoked function object

pub fn instanceof(&self, v: Val) -> bool

Checks whether this Val is an instanceof v

pub fn is_number(&self) -> bool

pub fn is_string(&self) -> bool

pub fn is_null(&self) -> bool

pub fn is_undefined(&self) -> bool

pub fn is_error(&self) -> bool

pub fn is_function(&self) -> bool

pub fn as_<T>(&self) -> T
where T: FromVal,