pub struct Symbol { /* private fields */ }Expand description
JavaScript Symbol type.
Symbols are a primitive data type in JavaScript that are guaranteed to be unique. They are often used as object keys to avoid naming collisions.
Implementations
Sourceimpl Symbol
impl Symbol
Sourcepub fn for_key(key: &str) -> Self
pub fn for_key(key: &str) -> Self
Creates a symbol from the global Symbol registry.
Arguments
key- The key to lookup/register in the global symbol registry
Returns
The symbol associated with the key
Examples
use jsbind::prelude::*;
let sym1 = Symbol::for_key("myKey");
let sym2 = Symbol::for_key("myKey");
// sym1 and sym2 refer to the same symbolSourcepub fn key_for(&self) -> Option<String>
pub fn key_for(&self) -> Option<String>
Gets the key for this symbol from the global symbol registry.
Returns
The key if this symbol is in the global registry, None otherwise
Examples
use jsbind::prelude::*;
let sym = Symbol::for_key("myKey");
assert_eq!(sym.key_for(), Some("myKey".to_string()));
let local_sym = Symbol::new(None);
assert_eq!(local_sym.key_for(), None);Sourcepub fn description(&self) -> Option<String>
pub fn description(&self) -> Option<String>
Sourcepub fn to_string_repr(&self) -> String
pub fn to_string_repr(&self) -> String
Sourcepub fn async_iterator() -> Self
pub fn async_iterator() -> Self
Symbol.asyncIterator
Sourcepub fn has_instance() -> Self
pub fn has_instance() -> Self
Symbol.hasInstance
Sourcepub fn is_concat_spreadable() -> Self
pub fn is_concat_spreadable() -> Self
Symbol.isConcatSpreadable
Sourcepub fn to_primitive() -> Self
pub fn to_primitive() -> Self
Symbol.toPrimitive
Sourcepub fn to_string_tag() -> Self
pub fn to_string_tag() -> Self
Symbol.toStringTag
Sourcepub fn unscopables() -> Self
pub fn unscopables() -> Self
Symbol.unscopables
Methods from Deref<Target = Any>
Sourcepub fn has_own_property(&self, prop: &str) -> bool
pub fn has_own_property(&self, prop: &str) -> bool
Checks whether a non-inherited property prop exists
Sourcepub fn at<T>(&self, idx: T) -> Val
pub fn at<T>(&self, idx: T) -> Val
Gets the element at index idx. Assumes the underlying js type is indexable
Sourcepub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
pub fn to_vec<V>(&self) -> Vec<V>where
V: FromVal,
Converts the underlying js array to a Vec of V
Sourcepub fn call(&self, f: &str, args: &[Val]) -> Val
pub fn call(&self, f: &str, args: &[Val]) -> Val
Calls the method f with args, can return an undefined js value
Sourcepub fn new(&self, args: &[Val]) -> Val
pub fn new(&self, args: &[Val]) -> Val
Calls the object’s constructor with args constructing a new object
Sourcepub fn invoke(&self, args: &[Val]) -> Val
pub fn invoke(&self, args: &[Val]) -> Val
Invokes the function object with args, can return an undefined js value
Sourcepub fn instanceof(&self, v: Val) -> bool
pub fn instanceof(&self, v: Val) -> bool
Checks whether this Val is an instanceof v
pub fn is_number(&self) -> bool
pub fn is_bool(&self) -> bool
pub fn is_string(&self) -> bool
pub fn is_null(&self) -> bool
pub fn is_undefined(&self) -> bool
pub fn is_error(&self) -> bool
pub fn is_function(&self) -> bool
Sourcepub fn as_<T>(&self) -> Twhere
T: FromVal,
pub fn as_<T>(&self) -> Twhere
T: FromVal,
Examples found in repository?
3fn main() {
4 emlite::init();
5 // Create Any from different Rust types
6 let num = Any::from(123);
7 let text = Any::from("hello");
8 let boolean = Any::from(true);
9 println!("Any from int: {:?}", num);
10 println!("Any from str: {:?}", text);
11 println!("Any from bool: {:?}", boolean);
12 Console::get().log(&[num.clone(), text.clone(), boolean.clone()]);
13
14 // Convert Any back to Rust types using as_::<T>()
15 let n: i32 = num.as_();
16 let s: Option<String> = text.as_();
17 let b: bool = boolean.as_();
18 println!("Extracted i32: {}", n);
19 println!("Extracted String: {:?}", s);
20 println!("Extracted bool: {}", b);
21}More examples
4fn main() {
5 emlite::init();
6
7 // 0-arg closure returning a number
8 let c0 = Closure::bind0(|| 42);
9 let f0: Function = (&c0).into();
10 let r0 = f0.call(&Any::undefined(), &[]).unwrap().as_::<i32>();
11 Console::get().log(&[Any::from(r0)]);
12
13 // 1-arg closure: add 1
14 let c1 = Closure::bind1(|x: i32| x + 1);
15 let f1: Function = (&c1).into();
16 let r1 = f1
17 .call(&Any::undefined(), &[Any::from(9)])
18 .unwrap()
19 .as_::<i32>();
20 Console::get().log(&[Any::from(r1)]);
21
22 // 2-arg closure: sum
23 let c2 = Closure::bind2(|a: i32, b: i32| a + b);
24 let f2: Function = (&c2).into();
25 let r2 = f2
26 .call(&Any::undefined(), &[Any::from(2), Any::from(3)])
27 .unwrap()
28 .as_::<i32>();
29 Console::get().log(&[Any::from(r2)]);
30
31 // 3-arg closure: format string
32 let c3 = Closure::bind3(|a: i32, b: i32, c: i32| format!("{}-{}-{}", a, b, c));
33 let f3: Function = (&c3).into();
34 let r3 = f3
35 .call(
36 &Any::undefined(),
37 &[Any::from(1), Any::from(2), Any::from(3)],
38 )
39 .unwrap()
40 .as_::<Option<String>>()
41 .unwrap();
42 Console::get().log(&[Any::from(r3)]);
43
44 // 4-arg closure: sum of four
45 let c4 = Closure::bind4(|a: i32, b: i32, c: i32, d: i32| a + b + c + d);
46 let f4: Function = (&c4).into();
47 let r4 = f4
48 .call(
49 &Any::undefined(),
50 &[Any::from(1), Any::from(2), Any::from(3), Any::from(4)],
51 )
52 .unwrap()
53 .as_::<i32>();
54 Console::get().log(&[Any::from(r4)]);
55}Trait Implementations
Sourceimpl DynCast for Symbol
impl DynCast for Symbol
Sourcefn instanceof(val: &Val) -> bool
fn instanceof(val: &Val) -> bool
val instanceof ThisType.Sourcefn unchecked_from_val(v: Val) -> Self
fn unchecked_from_val(v: Val) -> Self
Val into Self.Sourcefn unchecked_from_val_ref(v: &Val) -> &Self
fn unchecked_from_val_ref(v: &Val) -> &Self
&Val into &Self.Sourcefn unchecked_from_val_mut(v: &mut Val) -> &mut Self
fn unchecked_from_val_mut(v: &mut Val) -> &mut Self
&mut Val into &mut Self.fn has_type<T>(&self) -> boolwhere
T: DynCast,
fn dyn_into<T>(self) -> Result<T, Self>where
T: DynCast,
fn dyn_ref<T>(&self) -> Option<&T>where
T: DynCast,
fn dyn_mut<T>(&mut self) -> Option<&mut T>where
T: DynCast,
fn unchecked_into<T>(self) -> Twhere
T: DynCast,
fn unchecked_ref<T>(&self) -> &Twhere
T: DynCast,
fn unchecked_mut<T>(&mut self) -> &mut Twhere
T: DynCast,
fn is_instance_of<T>(&self) -> boolwhere
T: DynCast,
Sourcefn is_type_of(val: &Val) -> bool
fn is_type_of(val: &Val) -> bool
instanceof.