Struct TypedWeakSet

pub struct TypedWeakSet<T> { /* private fields */ }
TypedWeakSet<T> – Typed wrapper around ECMAScript “WeakSet” (new WeakSet()).

Implementations

Source

impl<T> TypedWeakSet<T>

pub fn new() -> Self

new WeakSet() — empty set.

pub fn size(&self) -> usize

set.size

pub fn add(&mut self, value: T)
where Val: From<T>,

set.add(value) — returns &mut Self for chaining (matches JS).

pub fn delete(&mut self, value: T) -> bool
where Val: From<T>,

set.delete(value)bool

pub fn clear(&mut self)

set.clear()

pub fn get(&self, idx: usize) -> Option<T>
where T: FromVal,

Return a copy of the element at idx converted to T.

pub fn has(&self, val: T) -> bool
where Val: From<T>,

Returns whether a value exists in the sequence.

pub fn set(&self, idx: usize, val: T)
where T: FromVal, Val: From<T>,

pub fn len(&self) -> usize

Methods from Deref<Target = Val>

pub fn get<T>(&self, prop: T) -> Val
where T: Into<Val>,

Gets the property prop

pub fn set<K, V>(&self, prop: K, val: V)
where K: Into<Val>, V: Into<Val>,

Set the underlying js object property prop to val

pub fn has<T>(&self, prop: T) -> bool
where T: Into<Val>,

Checks whether a property prop exists

pub fn has_own_property(&self, prop: &str) -> bool

Checks whether a non-inherited property prop exists

pub fn type_of(&self) -> String

Gets the typeof the underlying js object

pub fn at<T>(&self, idx: T) -> Val
where T: Into<Val>,

Gets the element at index idx. Assumes the underlying js type is indexable

pub fn to_vec<V>(&self) -> Vec<V>
where V: FromVal,

Converts the underlying js array to a Vec of V

pub fn call(&self, f: &str, args: &[Val]) -> Val

Calls the method f with args, can return an undefined js value

pub fn new(&self, args: &[Val]) -> Val

Calls the object’s constructor with args constructing a new object

pub fn invoke(&self, args: &[Val]) -> Val

Invokes the function object with args, can return an undefined js value

pub fn await_(&self) -> Val

Awaits the invoked function object

pub fn instanceof(&self, v: Val) -> bool

Checks whether this Val is an instanceof v

pub fn is_number(&self) -> bool

pub fn is_string(&self) -> bool

pub fn is_null(&self) -> bool

pub fn is_undefined(&self) -> bool

pub fn is_error(&self) -> bool

pub fn is_function(&self) -> bool

pub fn as_<T>(&self) -> T
where T: FromVal,